@@ -132,7 +132,7 @@ NMEA_PAYLOADS_GET = {
         "altUnit": CH,
         "sep": DE,
         "sepUnit": CH,
-        "diffAge": IN,
+        "diffAge": DE,
         "diffStation": IN,
     },
     "GLL": {
@@ -341,7 +341,7 @@ NMEA_PAYLOADS_GET = {
         "gdUnit": CH,  # NMEA >=4.00 only
     },
     "VTG": {
-        "cogT": DE,  # course over ground (true)
+        "cogt": DE,  # course over ground (true)
         "cogtUnit": CH,
         "cogm": DE,  # course over ground (magnetic)
         "cogmUnit": CH,
