@@ -12,10 +12,7 @@ Created on 4 Mar Sep 2021
 :author: semuadmin
 """
 
-from pynmeagps.nmeatypes_core import (
-    IN,
-    ST,
-)
+from pynmeagps.nmeatypes_core import ST
 
 NMEA_PAYLOADS_POLL = {
     # *********************************************
@@ -43,12 +40,12 @@ NMEA_PAYLOADS_POLL = {
     # PROPRIETARY MESSAGES
     # *********************************************
     "UBX00": {
-        "msgId": IN,  # 00
+        "msgId": ST,  # '00'
     },
     "UBX03": {
-        "msgId": IN,  # 03
+        "msgId": ST,  # '03'
     },
     "UBX04": {
-        "msgId": IN,  # 04
+        "msgId": ST,  # '04'
     },
 }
